Pi Hat ID EEPROM library
========================

[![Build Status](https://travis-ci.org/unipartdigital/pihat.svg?branch=master)](https://travis-ci.org/unipartdigital/pihat)
[![Coverage Status](https://coveralls.io/repos/github/unipartdigital/pihat/badge.svg?branch=master)](https://coveralls.io/github/unipartdigital/pihat?branch=master)

This package provides a Python library for manipulating the ID EEPROM
used to automatically identify a Raspberry Pi Hat add-on board.
